@@ -64,13 +64,7 @@ def _cursor_fetchone(self):
 
 
 def _cursor_fetchall(self):
-    results = []
-    lookup = _create_lookup_dict(self.description)
-    while True:
-        result = self._fetchone()
-        if result==None:
-            return results
-        results.append(DictRow(result,lookup))
+    return list(self)
 
 
 def _cursor_iter(self):
